================================
Welcome to Abed's documentation!
================================

This site covers the usage and API documentation of Abed. For information on 
what Abed is, see the :doc:`index` page.

Tutorial
--------

The Abed tutorial gives an overview of the basic setup of a new Abed project.  
It can be found here: :doc:`usage/tutorial`.


.. _usage-docs:

Usage documentation
-------------------

For a complete overview of how Abed can be used beyond what is covered in the 
:doc:`usage/tutorial`, there is the usage documentation.

.. toctree::
    :maxdepth: 2
    :glob:

    usage/*


.. _api_docs:

API documentation
-----------------

For information on the internals of Abed, each function has been 
documented using docstrings. This results in autogenerated API documentation, 
which can be found through the following links.

Core functionality:

.. toctree::
    :maxdepth: 2
    :glob:

    api/core/*

Result management:

.. toctree::
    :maxdepth: 2
    :glob:

    api/results/*

HTML generation:

.. toctree::
    :maxdepth: 2
    :glob:

    api/html/*

